/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerFlow;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerFlowMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerFlowAddParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerFlowEditParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerFlowIdParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerFlowPageParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerFlowService;

import java.util.List;

/**
 * 服务客户资金流水Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:40
 **/
@Service
public class BizServiceCustomerFlowServiceImpl extends ServiceImpl<BizServiceCustomerFlowMapper, BizServiceCustomerFlow> implements BizServiceCustomerFlowService {

    @Override
    public Page<BizServiceCustomerFlow> page(BizServiceCustomerFlowPageParam bizServiceCustomerFlowPageParam) {
        QueryWrapper<BizServiceCustomerFlow> queryWrapper = new QueryWrapper<BizServiceCustomerFlow>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerFlowPageParam.getSortField(), bizServiceCustomerFlowPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerFlowPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerFlowPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerFlowPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizServiceCustomerFlow::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerFlowAddParam bizServiceCustomerFlowAddParam) {
        BizServiceCustomerFlow bizServiceCustomerFlow = BeanUtil.toBean(bizServiceCustomerFlowAddParam, BizServiceCustomerFlow.class);
        this.save(bizServiceCustomerFlow);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerFlowEditParam bizServiceCustomerFlowEditParam) {
        BizServiceCustomerFlow bizServiceCustomerFlow = this.queryEntity(bizServiceCustomerFlowEditParam.getId());
        BeanUtil.copyProperties(bizServiceCustomerFlowEditParam, bizServiceCustomerFlow);
        this.updateById(bizServiceCustomerFlow);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerFlowIdParam> bizServiceCustomerFlowIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizServiceCustomerFlowIdParamList, BizServiceCustomerFlowIdParam::getId));
    }

    @Override
    public BizServiceCustomerFlow detail(BizServiceCustomerFlowIdParam bizServiceCustomerFlowIdParam) {
        return this.queryEntity(bizServiceCustomerFlowIdParam.getId());
    }

    @Override
    public BizServiceCustomerFlow queryEntity(String id) {
        BizServiceCustomerFlow bizServiceCustomerFlow = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomerFlow)) {
            throw new CommonException("服务客户资金流水不存在，id值为：{}", id);
        }
        return bizServiceCustomerFlow;
    }
}
