/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomer;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerAddParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerEditParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerIdParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerPageParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerService;

import java.util.List;

/**
 * 服务客户管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:27
 **/
@Service
public class BizServiceCustomerServiceImpl extends ServiceImpl<BizServiceCustomerMapper, BizServiceCustomer> implements BizServiceCustomerService {

    @Override
    public Page<BizServiceCustomer> page(BizServiceCustomerPageParam bizServiceCustomerPageParam) {
        QueryWrapper<BizServiceCustomer> queryWrapper = new QueryWrapper<BizServiceCustomer>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerPageParam.getSortField(), bizServiceCustomerPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizServiceCustomer::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerAddParam bizServiceCustomerAddParam) {
        BizServiceCustomer bizServiceCustomer = BeanUtil.toBean(bizServiceCustomerAddParam, BizServiceCustomer.class);
        this.save(bizServiceCustomer);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerEditParam bizServiceCustomerEditParam) {
        BizServiceCustomer bizServiceCustomer = this.queryEntity(bizServiceCustomerEditParam.getId());
        BeanUtil.copyProperties(bizServiceCustomerEditParam, bizServiceCustomer);
        this.updateById(bizServiceCustomer);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerIdParam> bizServiceCustomerIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizServiceCustomerIdParamList, BizServiceCustomerIdParam::getId));
    }

    @Override
    public BizServiceCustomer detail(BizServiceCustomerIdParam bizServiceCustomerIdParam) {
        return this.queryEntity(bizServiceCustomerIdParam.getId());
    }

    @Override
    public BizServiceCustomer queryEntity(String id) {
        BizServiceCustomer bizServiceCustomer = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomer)) {
            throw new CommonException("服务客户管理不存在，id值为：{}", id);
        }
        return bizServiceCustomer;
    }
}
